package edu.stanford.cs247;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.view.MotionEvent;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import edu.stanford.cs247.util.ColorHandler;

/**
 * CS247 Project 3: Mobile Ambient Display
 * 
 * This class provides scaffolding for creating your own mobile ambient
 * display. By default, it uses a simple message handler to change the
 * screen color. Replace this with your own code to update the display
 * in a creative and informative way based on some form of sensed input,
 * using the phone's on-board sensors and/or sensed "events" from the
 * Internet.
 */
public class MobileAmbientDisplay extends Activity {

	/**
	 * An ambient display view, that fills the screen with a single color.
	 */
	private AmbientDisplay mDisplay;
	
	/**
	 * Called when the activity is first created.
	 */
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        // run the application in full screen mode
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        getWindow().setFlags(
        		WindowManager.LayoutParams.FLAG_FULLSCREEN,
        		WindowManager.LayoutParams.FLAG_FULLSCREEN);
        
        // add the color display to the application
        mDisplay = new AmbientDisplay(this);
        setContentView(mDisplay);
        
        // exit the application upon screen touch
        // (NOTE: feel free to remove or replace this)
        mDisplay.setOnTouchListener(new View.OnTouchListener() {
        	public boolean onTouch(View v, MotionEvent event) {
				MobileAmbientDisplay.this.finish();
				return true;
			}
		});

        new ColorHandler(mDisplay).start();
    }
    
    /**
     * Called when the activity is resumed.
     */
    protected void onResume() {
    	super.onResume();
    }

    /**
     * Called when the activity is paused.
     */
    protected void onPause() {
    	super.onPause();
    }
    
    /**
     * Called when the activity is stopped.
     */
    protected void onStop() {
    	super.onStop();
    }
    
    /**
     * An optional helper method for showing an alert dialog.
     * May be helpful for debugging.
     */
    public void alertbox(String title, String mymessage)
    {
    	new AlertDialog.Builder(this)
    		.setMessage(mymessage)
    		.setTitle(title)
    		.setCancelable(true)
    		.setNeutralButton(android.R.string.cancel,
    			new DialogInterface.OnClickListener() {
    				public void onClick(DialogInterface dialog, int which) { }
    			})
    		.show();
    }
	
}
